@@ -52,5 +52,5 @@ class Predicate:
     __repr__ = __str__
 
     def __call__(self, *args):
-        from .formulas import Atom
+        from .formulas import Atom  # pylint: disable=import-outside-toplevel  # Avoiding circular references
         return Atom(self, args)
