@@ -1,8 +1,6 @@
 
-from .substitutions import TermSubstitution, term_substitution
 from .nnf import NNFTransformation, to_negation_normal_form
 from .cnf import CNFTransformation, to_conjunctive_normal_form
 from .prenex import PrenexTransformation, to_prenex_negation_normal_form
 from .quantifier_elimination import QuantifierElimination, QuantifierEliminationMode, remove_quantifiers
 from .neg_builtin import NegatedBuiltinAbsorption
-from .universal_effect_elimination import expand_universal_effect, compile_universal_effects_away
